@@ -8,8 +8,6 @@ from cfscrape import CloudflareScraper
 from cfscrape import create_scraper
 from requests import Response
 from requests import get as get_raw
-from requests.exceptions import ConnectTimeout
-from requests.exceptions import ConnectionError
 
 root = "https://www.furaffinity.net"
 
@@ -18,16 +16,12 @@ def join_url(*url_comps: Union[str, int]) -> str:
     return "/".join(map(lambda e: str(e).strip(" /"), url_comps))
 
 
-def ping() -> bool:
-    try:
-        return get_raw(root).ok
-    except (ConnectionError, ConnectTimeout):
-        return False
+def ping():
+    get_raw(root).raise_for_status()
 
 
 def make_session(cookies: List[dict]) -> Optional[CloudflareScraper]:
-    if not ping():
-        return None
+    ping()
 
     cookies = [
         {"name": cookie["name"], "value": cookie["value"]}
