@@ -8,6 +8,10 @@ from bs4.element import Tag
 from dateutil.parser import parse as parse_date
 
 
+class ParsingError(Exception):
+    pass
+
+
 def parse_page(text: str) -> BeautifulSoup:
     return BeautifulSoup(text, "lxml")
 
